[Rt-commit] rt branch, 4.0/pod-spell, updated. rt-4.0.0rc6-181-g715a3d2

Shawn Moore sartak at bestpractical.com
Thu Mar 17 21:42:15 EDT 2011


The branch, 4.0/pod-spell has been updated
       via  715a3d27e977ff662d48cdc4b7045dbc7f6597e1 (commit)
       via  ea56717bd6283b66c3c9f9a3ec18c35c46514f08 (commit)
       via  09f797502beff40b8c2024515019c711ee23a1a5 (commit)
       via  465ee2fa50a933f5ff43b5af75e7e7d90015ab47 (commit)
       via  32ab38472fdf9269c4e3a9f0587d4ac7b62bdf40 (commit)
       via  e96eb7375f513342433a2a2cf7a896e064d3c87a (commit)
       via  141663f3975c663849c71662ac1c666cb11dc671 (commit)
      from  4b98652980e06c0d8c87812a79b300d531ed35ce (commit)

Summary of changes:
 lib/RT/Action/Autoreply.pm        |    2 +-
 lib/RT/Action/CreateTickets.pm    |   10 ++--
 lib/RT/Action/EscalatePriority.pm |    2 +-
 lib/RT/Action/LinearEscalate.pm   |    8 +-
 lib/RT/Action/Notify.pm           |    2 +-
 lib/RT/Action/SendEmail.pm        |    4 +-
 lib/RT/Action/SetStatus.pm        |    2 +-
 lib/RT/Condition/CloseTicket.pm   |    6 +-
 lib/RT/Condition/ReopenTicket.pm  |    6 +-
 lib/RT/Crypt/GnuPG.pm             |  130 +++++++++++++++++++++++--------------
 lib/RT/Interface/CLI.pm           |   37 ++++++-----
 lib/RT/Interface/Email.pm         |   18 +++--
 lib/RT/Interface/Web.pm           |   37 ++++++-----
 lib/RT/Shredder/Constants.pm      |    7 +-
 lib/RT/Shredder/Dependencies.pm   |    2 +-
 lib/RT/Shredder/Plugin.pm         |   20 +++---
 t/99-pod-spelling.t               |    9 +++
 17 files changed, 174 insertions(+), 128 deletions(-)

- Log -----------------------------------------------------------------
commit 141663f3975c663849c71662ac1c666cb11dc671
Author: Shawn M Moore <sartak at bestpractical.com>
Date:   Thu Mar 17 21:06:16 2011 -0400

    Spellcheck lib/Rt/Action/*

diff --git a/lib/RT/Action/Autoreply.pm b/lib/RT/Action/Autoreply.pm
index 90bdea6..c87ea41 100644
--- a/lib/RT/Action/Autoreply.pm
+++ b/lib/RT/Action/Autoreply.pm
@@ -87,7 +87,7 @@ sub SetRecipients {
 
 =head2 SetReturnAddress
 
-Set this message\'s return address to the apropriate queue address
+Set this message's return address to the appropriate queue address
 
 =cut
 
diff --git a/lib/RT/Action/CreateTickets.pm b/lib/RT/Action/CreateTickets.pm
index 54f69d5..f9bcd0d 100644
--- a/lib/RT/Action/CreateTickets.pm
+++ b/lib/RT/Action/CreateTickets.pm
@@ -75,7 +75,7 @@ Create one or more tickets according to an externally supplied template.
 
 Using the "CreateTickets" ScripAction and mandatory dependencies, RT now has 
 the ability to model complex workflow. When a ticket is created in a queue
-that has a "CreateTickets" scripaction, that ScripAction parses its "Template"
+that has a "CreateTickets" scrip action, that ScripAction parses its "Template"
 
 
 
@@ -176,7 +176,7 @@ A convoluted example
  
 =head2 Acceptable fields
 
-A complete list of acceptable fields for this beastie:
+A complete list of acceptable fields for this action:
 
 
     *  Queue           => Name or id# of a queue
@@ -225,7 +225,7 @@ A complete list of acceptable fields for this beastie:
 Fields marked with an * are required.
 
 Fields marked with a + may have multiple values, simply
-by repeating the fieldname on a new line with an additional value.
+by repeating the field name on a new line with an additional value.
 
 Fields marked with a ! are postponed to be processed after all
 tickets in the same actions are created.  Except for 'Status', those
@@ -234,7 +234,7 @@ the identifiers after ==Create-Ticket), instead of raw Ticket ID
 numbers.
 
 When parsed, field names are converted to lowercase and have -s stripped.
-Refers-To, RefersTo, refersto, refers-to and r-e-f-er-s-tO will all 
+C<Refers-To>, C<RefersTo>, C<refersto>, C<refers-to> and C<r-e-f-er-s-tO> will all 
 be treated as the same thing.
 
 
@@ -560,7 +560,7 @@ sub Parse {
 
 =head2 _ParseMultilineTemplate
 
-Parses mulitline templates. Things like:
+Parses multiline templates. Things like:
 
  ===Create-Ticket ... 
 
diff --git a/lib/RT/Action/EscalatePriority.pm b/lib/RT/Action/EscalatePriority.pm
index 090695c..6c9af43 100644
--- a/lib/RT/Action/EscalatePriority.pm
+++ b/lib/RT/Action/EscalatePriority.pm
@@ -61,7 +61,7 @@ EsclatePriority uses the following formula to change a ticket's priority:
 
     Priority = Priority +  (( FinalPriority - Priority ) / ( DueDate-Today))
 
-Unless the duedate is past, in which case priority gets bumped straight
+Unless the due date is past, in which case priority gets bumped straight
 to final priority.
 
 In this way, priority is either increased or decreased toward the final priority
diff --git a/lib/RT/Action/LinearEscalate.pm b/lib/RT/Action/LinearEscalate.pm
index 3e54320..b8be33a 100644
--- a/lib/RT/Action/LinearEscalate.pm
+++ b/lib/RT/Action/LinearEscalate.pm
@@ -58,10 +58,10 @@ This action honor the Starts date.
 
 This action can apply changes silently.
 
-This action can replace EscalatePriority completly. If you want to tickets
+This action can replace EscalatePriority completely. If you want to tickets
 that have been created without Due date then you can add scrip that sets
 default due date. For example a week then priorities of your tickets will
-escalate linearly during the week from intial value towards final.
+escalate linearly during the week from initial value towards final.
 
 =head1 This vs. LinearEscalate from the CPAN
 
@@ -91,9 +91,9 @@ will get tickets to where they need to be:
     "(Status='new' OR Status='open' OR Status = 'stalled')" \
     --action RT::Action::LinearEscalate
 
-The Starts date is associated with intial ticket's priority or
+The Starts date is associated with the initial ticket's priority or
 the Created field if the former is not set. End of interval is
-the Due date. Tickets without due date B<are not updated>.
+the Due date. Tickets without a due date B<are not updated>.
 
 =head1 CONFIGURATION
 
diff --git a/lib/RT/Action/Notify.pm b/lib/RT/Action/Notify.pm
index b999426..475b8c7 100644
--- a/lib/RT/Action/Notify.pm
+++ b/lib/RT/Action/Notify.pm
@@ -71,7 +71,7 @@ sub Prepare {
 
 =head2 SetRecipients
 
-Sets the recipients of this meesage to Owner, Requestor, AdminCc, Cc or All. 
+Sets the recipients of this message to Owner, Requestor, AdminCc, Cc or All. 
 Explicitly B<does not> notify the creator of the transaction by default
 
 =cut
diff --git a/lib/RT/Action/SendEmail.pm b/lib/RT/Action/SendEmail.pm
index 1559a07..7839cdd 100644
--- a/lib/RT/Action/SendEmail.pm
+++ b/lib/RT/Action/SendEmail.pm
@@ -860,7 +860,7 @@ sub SetReturnAddress {
 
 }
 
-=head2 SetFrom ( From => emailaddress )
+=head2 SetFrom ( From => address )
 
 Set the From: address for outgoing email
 
@@ -1100,7 +1100,7 @@ sub SetHeaderAsEncoding {
 Takes a perl string and optional encoding pass it over
 L<RT::Interface::Email/EncodeToMIME>.
 
-Basicly encode a string using B encoding according to RFC2047.
+Basically, encodes the string using B encoding according to RFC2047.
 
 =cut
 
diff --git a/lib/RT/Action/SetStatus.pm b/lib/RT/Action/SetStatus.pm
index adc836a..17a5506 100644
--- a/lib/RT/Action/SetStatus.pm
+++ b/lib/RT/Action/SetStatus.pm
@@ -60,7 +60,7 @@ RT::Action::SetStatus - RT's scrip action to set status of a ticket
 
 This action changes status to a new value according to the rules in L</ARGUMENT>.
 Status is not changed if the transition is invalid or another error occurs. All
-issues are logged at apropriate levels.
+issues are logged at appropriate levels.
 
 =head1 ARGUMENT
 
diff --git a/t/99-pod-spelling.t b/t/99-pod-spelling.t
index 5ba4239..14f480d 100644
--- a/t/99-pod-spelling.t
+++ b/t/99-pod-spelling.t
@@ -105,6 +105,7 @@ unary
 UTF-8
 reparenting
 RSS
+uninstall
 
 # RT JARGON
 ACEs
@@ -125,6 +126,7 @@ RT's
 Requestor
 requestor
 Requestors
+requestors
 crontool
 lifecycle
 lifecycles

commit e96eb7375f513342433a2a2cf7a896e064d3c87a
Author: Shawn M Moore <sartak at bestpractical.com>
Date:   Thu Mar 17 21:07:15 2011 -0400

    Spellcheck lib/RT/Condition/*

diff --git a/lib/RT/Condition/CloseTicket.pm b/lib/RT/Condition/CloseTicket.pm
index ec3c24f..5cbc53c 100644
--- a/lib/RT/Condition/CloseTicket.pm
+++ b/lib/RT/Condition/CloseTicket.pm
@@ -56,9 +56,9 @@ use base 'RT::Condition';
 
 =head2 IsApplicable
 
-If the ticket was closed, ie status was changed from any active status to
-an inactive. See F<RT_Config.pm> for C<ActiveStatuses> and C<InactiveStatuses>
-options.
+If the ticket was closed, i.e. status was changed from any active status to an
+inactive status. See F<RT_Config.pm> for C<ActiveStatuses> and
+C<InactiveStatuses> options.
 
 =cut
 
diff --git a/lib/RT/Condition/ReopenTicket.pm b/lib/RT/Condition/ReopenTicket.pm
index cf1b91f..569df3b 100644
--- a/lib/RT/Condition/ReopenTicket.pm
+++ b/lib/RT/Condition/ReopenTicket.pm
@@ -56,9 +56,9 @@ use base 'RT::Condition';
 
 =head2 IsApplicable
 
-If the ticket was repopened, ie status was changed from any inactive status to
-an active. See F<RT_Config.pm> for C<ActiveStatuses> and C<InactiveStatuses>
-options.
+If the ticket was reopened, i.e. status was changed from any inactive status to
+an active status. See F<RT_Config.pm> for C<ActiveStatuses> and
+C<InactiveStatuses> options.
 
 =cut
 

commit 32ab38472fdf9269c4e3a9f0587d4ac7b62bdf40
Author: Shawn M Moore <sartak at bestpractical.com>
Date:   Thu Mar 17 21:20:40 2011 -0400

    Spellcheck lib/RT/Crypt/GnuPG.pm

diff --git a/lib/RT/Crypt/GnuPG.pm b/lib/RT/Crypt/GnuPG.pm
index 44d4286..05115d2 100644
--- a/lib/RT/Crypt/GnuPG.pm
+++ b/lib/RT/Crypt/GnuPG.pm
@@ -71,11 +71,11 @@ You can control the configuration of this subsystem from RT's configuration file
 Some options are available via the web interface, but to enable this functionality, you
 MUST start in the configuration file.
 
-There are two hashes, GnuPG and GnuPGOptions in the configuration file. The 
+There are two hashes, GnuPG and GnuPGOptions in the configuration file. The
 first one controls RT specific options. It enables you to enable/disable facility 
-or change the format of messages. The second one is a hash with options for the 
-'gnupg' utility. You can use it to define a keyserver, enable auto-retrieval keys 
-and set almost any option 'gnupg' supports on your system.
+or change the format of messages. The second one is a hash with options for the
+C<gpg> utility. You can use it to define a keyserver, enable auto-retrieval keys
+and set almost any option C<gpg> supports on your system.
 
 =head2 %GnuPG
 
@@ -114,23 +114,23 @@ This framework implements two formats of signing and encrypting of email message
 
 =over
 
-=item RFC
+=item C<RFC>
 
 This format is also known as GPG/MIME and described in RFC3156 and RFC1847.
 Technique described in these RFCs is well supported by many mail user
 agents (MUA), but some MUAs support only inline signatures and encryption,
 so it's possible to use inline format (see below).
 
-=item Inline
+=item C<Inline>
 
 This format doesn't take advantage of MIME, but some mail clients do
 not support GPG/MIME.
 
 We sign text parts using clear signatures. For each attachments another
-attachment with a signature is added with '.sig' extension.
+attachment with a signature is added with F<.sig> extension.
 
 Encryption of text parts is implemented using inline format, other parts
-are replaced with attachments with the filename extension '.pgp'.
+are replaced with attachments with the filename extension F<.pgp>.
 
 This format is discouraged because modern mail clients typically don't support
 it well.
@@ -144,12 +144,12 @@ option C<AllowEncryptDataInDB>. By default it's disabled.
 Users must have rights to see and modify tickets to use
 this feature.
 
-=head2 %GnuPGOptions
+=head2 C<%GnuPGOptions>
 
-Use this hash to set options of the 'gnupg' program. You can define almost any
-option you want which  gnupg supports, but never try to set options which
-change output format or gnupg's commands, such as --sign (command),
---list-options (option) and other.
+Use this hash to set options of the C<gpg> program. You can define almost any
+option you want which  C<gpg> supports, but never set options which
+change the output format of C<gpg>'s commands, such as C<--sign> (command),
+C<--list-options> (option) and other.
 
 Some GnuPG options take arguments while others take none. (Such as  --use-agent).
 For options without specific value use C<undef> as hash value.
@@ -162,44 +162,45 @@ To disable these option just comment them out or delete them from the hash
     );
 
 B<NOTE> that options may contain '-' character and such options B<MUST> be
-quoted, otherwise you can see quite cryptic error 'gpg: Invalid option "--0"'.
+quoted, otherwise you can see a cryptic error like C<gpg: Invalid option "--0">.
 
 =over
 
-=item --homedir
+=item C<--homedir>
 
 The GnuPG home directory, by default it is set to F</opt/rt4/var/data/gpg>.
 
-You can manage this data with the 'gpg' commandline utility 
-using the GNUPGHOME environment variable or --homedir option. 
+You can manage this data with the C<gpg> command-line utility
+using the C<GNUPGHOME> environment variable or C<--homedir> option.
 Other utilities may be used as well.
 
 In a standard installation, access to this directory should be granted to
 the web server user which is running RT's web interface, but if you're running
 cronjobs or other utilities that access RT directly via API and may generate
 encrypted/signed notifications then the users you execute these scripts under
-must have access too. 
+must have access too.
 
-However, granting access to the dir to many users makes your setup less secure,
+However, granting access to the directory to many users makes your setup less secure,
 some features, such as auto-import of keys, may not be available if you do not.
 To enable this features and suppress warnings about permissions on
-the dir use --no-permission-warning.
+the directory use C<--no-permission-warning>.
 
-=item --digest-algo
+=item C<--digest-algo>
 
-This option is required in advance when RFC format for outgoing messages is
-used. We can not get default algorithm from gpg program so RT uses 'SHA1' by
-default. You may want to override it. You can use MD5, SHA1, RIPEMD160,
-SHA256 or other, however use `gpg --version` command to get information about
-supported algorithms by your gpg. These algorithms are listed as hash-functions.
+This option is required when the RFC format for outgoing messages is used. We
+cannot get the default algorithm from C<gpg> program, so RT uses C<SHA1> by
+default. You may want to override it. You can use C<MD5>, C<SHA1>,
+C<RIPEMD160>, C<SHA256> and others, however use the C<gpg --version> command to
+get information about algorithms supported by your C<gpg>. These algorithms are
+listed under "hash-functions".
 
-=item --use-agent
+=item C<--use-agent>
 
 This option lets you use GPG Agent to cache the passphrase of RT's key. See
 L<http://www.gnupg.org/documentation/manuals/gnupg/Invoking-GPG_002dAGENT.html>
 for information about GPG Agent.
 
-=item --passphrase
+=item C<--passphrase>
 
 This option lets you set the passphrase of RT's key directly. This option is
 special in that it isn't passed directly to GPG, but is put into a file that
@@ -209,7 +210,7 @@ the --use-agent option instead.
 
 =item other
 
-Read `man gpg` to get list of all options this program support.
+Read C<man gpg> to get a list of all the options this program supports.
 
 =back
 
@@ -220,9 +221,9 @@ default. As an administrative user of RT, open 'Configuration' then 'Queues',
 and select a queue. On the page you can see information about the queue's keys 
 at the bottom and two checkboxes to choose default actions.
 
-As well, encryption is enabled for autoreplies and other notifications when
-an encypted message enters system via mailgate interface even if queue's
-option is disabled.
+Also, encryption is enabled for autoreplies and other notifications when an
+encrypted message enters the system via the mailgate interface even if the
+queue's option is disabled.
 
 =head2 Handling incoming messages
 
@@ -231,9 +232,9 @@ To enable handling of encrypted and signed message in the RT you should add
 
     Set(@MailPlugins, 'Auth::MailFrom', 'Auth::GnuPG', ...other filter...);
 
-See also `perldoc lib/RT/Interface/Email/Auth/GnuPG.pm`.
+See also L<RT::Interface::Email::Auth::GnuPG>.
 
-=head2 Errors handling
+=head2 Error handling
 
 There are several global templates created in the database by default. RT
 uses these templates to send error messages to users or RT's owner. These 
@@ -256,10 +257,33 @@ his public key and won't be able to send him encrypted content. There are severa
 reasons why RT can't use a key. However, the actual reason is not sent to the user, 
 but sent to RT owner using 'Error to RT owner: public key'.
 
-The possible reasons: "Not Found", "Ambiguous specification", "Wrong
-key usage", "Key revoked", "Key expired", "No CRL known", "CRL too
-old", "Policy mismatch", "Not a secret key", "Key not trusted" or
-"No specific reason given".
+The possible reasons:
+
+=over 4
+
+=item C<Not Found>
+
+=item C<Ambiguous specification>
+
+=item C<Wrong key usage>
+
+=item C<Key revoked>
+
+=item C<Key expired>
+
+=item C<No CRL known>
+
+=item C<CRL too old>
+
+=item C<Policy mismatch>
+
+=item C<Not a secret key>
+
+=item C<Key not trusted>
+
+=item C<No specific reason given>
+
+=back
 
 Due to limitations of GnuPG, it's impossible to encrypt to an untrusted key,
 unless 'always trust' mode is enabled.
@@ -314,12 +338,18 @@ of error messages.
 
 =head2 Documentation and references
 
-* RFC1847 - Security Multiparts for MIME: Multipart/Signed and Multipart/Encrypted.
+=over 4
+
+=item RFC1847 - Security Multiparts for MIME: Multipart/Signed and Multipart/Encrypted.
+
 Describes generic MIME security framework, "mulitpart/signed" and "multipart/encrypted"
 MIME types.
 
-* RFC3156 - MIME Security with Pretty Good Privacy (PGP),
-updates RFC2015.
+=item RFC3156 - MIME Security with Pretty Good Privacy (PGP)
+
+Updates RFC2015.
+
+=back
 
 =cut
 
@@ -371,7 +401,7 @@ Signs and/or encrypts an email message with GnuPG utility.
 =item Signing
 
 During signing you can pass C<Signer> argument to set key we sign with this option
-overrides gnupg's C<default-key> option. If C<Signer> argument is not provided
+overrides C<gpg>'s C<default-key> option. If C<Signer> argument is not provided
 then address of a message sender is used.
 
 As well you can pass C<Passphrase>, but if value is undefined then L</GetPassphrase>
@@ -1572,9 +1602,9 @@ sub GetPassphrase {
 
 =head2 ParseStatus
 
-Takes a string containing output of gnupg status stream. Parses it and returns
-array of hashes. Each element of array is a hash ref and represents line or
-group of lines in the status message.
+Takes a string containing the output of a GnuPG status stream. Parses it and
+returns an array of hashes. Each hash ref represents a line or a group of lines
+in the status message.
 
 All hashes have Operation, Status and Message elements.
 
@@ -1582,7 +1612,7 @@ All hashes have Operation, Status and Message elements.
 
 =item Operation
 
-Classification of operations gnupg performs. Now we have support
+Classification of operations GnuPG performs. Now we have support
 for Sign, Encrypt, Decrypt, Verify, PassphraseCheck, RecipientsCheck and Data
 values.
 
@@ -1941,7 +1971,7 @@ Returns or sets identifier of the key that should be used for signing.
 
 Returns the current value when called without arguments.
 
-Sets new value when called with one argument and unsets if it's undef.
+Sets new value when called with one argument and unsets if it's C<undef>.
 
 =cut
 
@@ -2363,11 +2393,11 @@ sub ImportKey {
     return %res;
 }
 
-=head2 KEY
+=head2 DrySign
 
 Signs a small message with the key, to make sure the key exists and 
-we have a useable passphrase. The first argument MUST be a key identifier
-of the signer: either email address, key id or finger print.
+we have a usable passphrase. The first argument MUST be the key identifier
+of the signer: email address, key id, or finger print.
 
 Returns a true value if all went well.
 
diff --git a/t/99-pod-spelling.t b/t/99-pod-spelling.t
index 14f480d..ef88e3a 100644
--- a/t/99-pod-spelling.t
+++ b/t/99-pod-spelling.t
@@ -106,6 +106,12 @@ UTF-8
 reparenting
 RSS
 uninstall
+PGP
+SHA
+cronjobs
+unsets
+multiparts
+inline
 
 # RT JARGON
 ACEs
@@ -140,3 +146,4 @@ formatters
 lookup
 wipeout
 RTx
+autoreplies

commit 465ee2fa50a933f5ff43b5af75e7e7d90015ab47
Author: Shawn M Moore <sartak at bestpractical.com>
Date:   Thu Mar 17 21:24:46 2011 -0400

    Spellcheck lib/RT/Interface/CLI.pm

diff --git a/lib/RT/Interface/CLI.pm b/lib/RT/Interface/CLI.pm
index 231ae0d..6c8fa2b 100644
--- a/lib/RT/Interface/CLI.pm
+++ b/lib/RT/Interface/CLI.pm
@@ -72,27 +72,27 @@ BEGIN {
 
 =head1 SYNOPSIS
 
-  use lib "/path/to/rt/libraries/";
+    use lib "/path/to/rt/libraries/";
 
-  use RT::Interface::CLI  qw(CleanEnv 
-	  		   GetCurrentUser GetMessageContent loc);
+    use RT::Interface::CLI qw(CleanEnv GetCurrentUser GetMessageContent loc);
 
-  #Clean out all the nasties from the environment
-  CleanEnv();
+    # Clean out all the nasties from the environment.
+    CleanEnv();
 
-  #let's talk to RT'
-  use RT;
+    # Load RT's code.
+    use RT;
 
-  #Load RT's config file
-  RT::LoadConfig();
+    # Load RT's config file.
+    RT::LoadConfig();
 
-  # Connect to the database. set up loggign
-  RT::Init();
+    # Connect to the database. Set up logging.
+    RT::Init();
 
-  #Get the current user all loaded
-  my $CurrentUser = GetCurrentUser();
+    # Get the current user all loaded
+    my $CurrentUser = GetCurrentUser();
 
-  print loc('Hello!'); # Synonym of $CuurentUser->loc('Hello!');
+    # Synonym of $CuurentUser->loc('Hello!');
+    print loc('Hello!');
 
 =head1 DESCRIPTION
 
@@ -105,7 +105,7 @@ BEGIN {
 
 =head2 CleanEnv
 
-Removes some of the nastiest nasties from the user\'s environment.
+Removes some of the nastiest attack vectors from the user's environment.
 
 =cut
 
@@ -127,8 +127,9 @@ sub CleanEnv {
 
 =head2 GetCurrentUser
 
-  Figures out the uid of the current user and returns an RT::CurrentUser object
-loaded with that user.  if the current user isn't found, returns a copy of RT::Nobody.
+Figures out the uid of the current user and returns an L<RT::CurrentUser>
+object loaded with that user. If the current user isn't found, returns a copy
+of C<< RT->Nobody >>.
 
 =cut
 
@@ -157,7 +158,7 @@ sub GetCurrentUser  {
 
 =head2 loc
 
-  Synonym of $CurrentUser->loc().
+    Synonym of C<< $CurrentUser->loc("...") >>.
 
 =cut
 

commit 09f797502beff40b8c2024515019c711ee23a1a5
Author: Shawn M Moore <sartak at bestpractical.com>
Date:   Thu Mar 17 21:34:58 2011 -0400

    Spellcheck lib/RT/Interface/Email.pm

diff --git a/lib/RT/Interface/Email.pm b/lib/RT/Interface/Email.pm
index 2256526..901efeb 100644
--- a/lib/RT/Interface/Email.pm
+++ b/lib/RT/Interface/Email.pm
@@ -161,9 +161,9 @@ sub CheckForSuspiciousSender {
 
 =head2 CheckForAutoGenerated HEAD
 
-Takes a HEAD object of L<MIME::Head> class and returns true if message
-is autogenerated. Checks 'Precedence' and 'X-FC-Machinegenerated'
-fields of the head in tests.
+Takes a HEAD object of L<MIME::Head> class and returns true if we think the
+message is autogenerated. This is more black magic than science. We check
+C<Precedence>, C<Auto-Submitted>, C<X-FC-Machinegenerated>, etc. headers.
 
 =cut
 
@@ -200,9 +200,9 @@ sub CheckForBounce {
 }
 
 
-=head2 MailError PARAM HASH
+=head2 MailError PARAMHASH
 
-Sends an error message. Takes a param hash:
+Sends an error message. Takes a paramhash:
 
 =over 4
 
@@ -883,7 +883,7 @@ according to RFC2047, using B (base64 based) encoding.
 String must be a perl string, octets are returned.
 
 If Charset is not provided then $EmailOutputEncoding config option
-is used, or "latin-1" if that is not set.
+is used, or C<latin-1> if that is not set.
 
 =cut
 
@@ -1682,7 +1682,8 @@ sub _RunUnsafeAction {
 
 =head2 _NoAuthorizedUserFound
 
-Emails the RT Owner and the requestor when the auth plugins return "No auth user found"
+Emails the RT Owner and the requestor when the authentication plugins return
+C<No auth user found>.
 
 =cut
 
@@ -1729,7 +1730,8 @@ EOT
 
 =head2 _HandleMachineGeneratedMail
 
-Takes named params:
+Takes named parameters:
+
     Message
     ErrorsTo
     Subject

commit ea56717bd6283b66c3c9f9a3ec18c35c46514f08
Author: Shawn M Moore <sartak at bestpractical.com>
Date:   Thu Mar 17 21:38:53 2011 -0400

    Spellcheck lib/RT/Interface/Web.pm

diff --git a/lib/RT/Shredder/Constants.pm b/lib/RT/Shredder/Constants.pm
index 430be25..8e9f74f 100644
--- a/lib/RT/Shredder/Constants.pm
+++ b/lib/RT/Shredder/Constants.pm
@@ -60,8 +60,9 @@ RT::Shredder::Constants -  RT::Shredder constants that is used to mark state of
 =head1 DESCRIPTION
 
 This module exports two group of bit constants.
-First group is group of flags which are used to clarify dependecies between objects, and
-second group is states of RT objects in Shredder cache.
+
+The first group is a group of flags which clarify dependencies between objects.
+The second group is states of RT objects in the Shredder cache.
 
 =head1 FLAGS
 
@@ -109,7 +110,7 @@ loaded and placed into cache.
 =head2 WIPED
 
 Objects with this state are not exist any more in DB, but perl
-object is still in memory. This state is used to be shure that
+object is still in memory. This state is used to ensure that the
 delete query is called once.
 
 =head2 VALID
diff --git a/lib/RT/Shredder/Dependencies.pm b/lib/RT/Shredder/Dependencies.pm
index 753364f..08acc63 100644
--- a/lib/RT/Shredder/Dependencies.pm
+++ b/lib/RT/Shredder/Dependencies.pm
@@ -60,7 +60,7 @@ use RT::Record;
 
 =head2 new
 
-Creates new empty collection of dependecies.
+Creates new empty collection of dependencies.
 
 =cut
 
diff --git a/lib/RT/Shredder/Plugin.pm b/lib/RT/Shredder/Plugin.pm
index a8b4b92..f768e8b 100644
--- a/lib/RT/Shredder/Plugin.pm
+++ b/lib/RT/Shredder/Plugin.pm
@@ -83,10 +83,10 @@ RT::Shredder::Plugin - interface to access shredder plugins
 
 =head2 new
 
-Object constructor, returns new object. Takes optional hash
-as arguments, it's not required and this class doesn't use it,
+Object constructor, returns a new object. Takes an optional hash
+as arguments. It's not required and this class doesn't use it,
 but plugins could define some arguments and can handle them
-after your've load it.
+after you've created the object.
 
 =cut
 
@@ -149,7 +149,7 @@ sub List
 
 Takes name of the plugin as first argument, loads plugin,
 creates new plugin object and reblesses self into plugin
-if all steps were successfuly finished, then you don't need to
+if all steps were successfully finished, then you don't need to
 create new object for the plugin.
 
 Other arguments are sent to the constructor of the plugin
@@ -188,11 +188,11 @@ load plugin. The format of the string is
 exactly like in the L<rt-shredder> script. All other
 arguments are sent to the plugins constructor.
 
-Method does the same things as C<LoadByName>, but also
-checks if the plugin supports arguments and values are correct,
-so you can C<Run> specified plugin immediatly.
+This method does the same things as C<LoadByName>, but also checks if the
+plugin supports arguments and that their values are correct, so you can C<Run>
+the specified plugin immediately.
 
-Returns list with C<$status> and C<$message>. On errors status
+Returns a list with C<$status> and C<$message>. On error, status
 is C<false>.
 
 =cut
@@ -232,8 +232,8 @@ Instance method that takes one object as argument and rebless
 the current object into into class of the argument and copy data
 of the former. Returns nothing.
 
-Method is used by C<Load*> methods to automaticaly rebless
-C<RT::Shredder::Plugin> object into class of the loaded
+This method is used by C<Load*> methods to automatically rebless
+the C<RT::Shredder::Plugin> object into the class of the loaded
 plugin.
 
 =cut

-----------------------------------------------------------------------


More information about the Rt-commit mailing list
diff --git a/lib/RT/Interface/Web.pm b/lib/RT/Interface/Web.pm
index baedcc0..1c1be6b 100644
--- a/lib/RT/Interface/Web.pm
+++ b/lib/RT/Interface/Web.pm
@@ -138,9 +138,9 @@ sub EscapeURI {
 
 =head2 WebCanonicalizeInfo();
 
-Different web servers set different environmental varibles. This
-function must return something suitable for REMOTE_USER. By default,
-just downcase $ENV{'REMOTE_USER'}
+Different web servers set different environmental variables. This
+function must return something suitable for C<REMOTE_USER>. By default,
+just lowercase C<$ENV{'REMOTE_USER'}>.
 
 =cut
 
@@ -305,7 +305,7 @@ sub LoginError {
 
 =head2 SetNextPage [PATH]
 
-Intuits and stashes the next page in the sesssion hash.  If PATH is
+Intuits and stashes the next page in the session hash.  If PATH is
 specified, uses that instead of the value of L<IntuitNextPage()>.  Returns
 the hash value.
 
@@ -326,7 +326,7 @@ sub SetNextPage {
 =head2 TangentForLogin [HASH]
 
 Redirects to C</NoAuth/Login.html>, setting the value of L<IntuitNextPage> as
-the next page.  Optionally takes a hash which is dumped into query params.
+the next page.  Optionally takes a hash which is dumped into query parameters.
 
 =cut
 
@@ -416,8 +416,9 @@ sub MaybeShowInstallModePage {
 
 =head2 MaybeShowNoAuthPage  \%ARGS
 
-This function, called exclusively by RT's autohandler, dispatches
-a request to the page a user requested (but only if it matches the "noauth" regex.
+This function, called exclusively by RT's autohandler, dispatches a request to
+the page a user requested (but only if it matches the configured
+C<WebNoAuthRegex>)
 
 If it serves a page, it stops mason processing. Otherwise, mason just keeps running through the autohandler
 
@@ -451,10 +452,12 @@ sub InitializeMenu {
 =head2 ShowRequestedPage  \%ARGS
 
 This function, called exclusively by RT's autohandler, dispatches
-a request to the page a user requested (making sure that unpriviled users
-can only see self-service pages.
+a request to the page a user requested
 
-=cut 
+We make sure that unprivileged users can only see self-service
+pages.
+
+=cut
 
 sub ShowRequestedPage {
     my $ARGS = shift;
@@ -621,7 +624,7 @@ sub AttemptPasswordAuthentication {
         $m->callback( %$ARGS, CallbackName => 'SuccessfulLogin', CallbackPage => '/autohandler' );
 
         # Really the only time we don't want to redirect here is if we were
         # passed user and pass as query params in the URL.
         if ($next) {
             Redirect($next);
         }
@@ -738,8 +741,8 @@ sub Redirect {
 
 =head2 StaticFileHeaders 
 
-Send the browser a few headers to try to get it to (somewhat agressively)
-cache RT's static Javascript and CSS files.
+Send the browser a few headers to try to get it to (somewhat aggressively)
+cache RT's static JavaScript and CSS files.
 
 This routine could really use _accurate_ heuristics. (XXX TODO)
 
@@ -770,7 +773,7 @@ relative.
 
 This function does not consult the filesystem at all; it is merely
 a logical sanity checking of the path. This explicitly does not handle
-symlinks; if you have symlinks in RT's webroot pointing outside of it,
+symlinks; if you have symlinks in RT's web root pointing outside of it,
 then we assume you know what you are doing.
 
 =cut
@@ -1038,10 +1041,10 @@ sub PageWidgets {
 
 =head2 loc ARRAY
 
-loc is a nice clean global routine which calls $session{'CurrentUser'}->loc()
-with whatever it's called with. If there is no $session{'CurrentUser'}, 
+C<loc> is a nice clean global routine which calls C<< $session{'CurrentUser'}->loc() >>
+with whatever it's called with. If there is no C<< $session{'CurrentUser'} >>,
 it creates a temporary user, so we have something to get a localisation handle
-through
+through.
 
 =cut
 
@@ -621,7 +624,7 @@ sub AttemptPasswordAuthentication {
 
         # Really the only time we don't want to redirect here is if we were
-        # passed user and pass as query params in the URL.
+        # passed user and pass as query parameters in the URL.
         if ($next) {
             Redirect($next);

commit 715a3d27e977ff662d48cdc4b7045dbc7f6597e1
Author: Shawn M Moore <sartak at bestpractical.com>
Date:   Thu Mar 17 21:42:04 2011 -0400

    Spellcheck lib/RT/Shredder/*
